@@ -60,8 +60,8 @@ class NDVariable:
         else:
             self.shape = 1
 
-        if isinstance(initial, int) or isinstance(initial, float):
-            initial = np.array([initial])
+        # if isinstance(initial, int) or isinstance(initial, float):
+        #     initial = np.array([initial])
 
         match = U_RE.match(name)
         self.unit = (match.group("unit") or "").strip()
@@ -72,8 +72,11 @@ class NDVariable:
 
     def append(self, *args):
         """Creates a 1D array and appends it to the list."""
-        arr = np.array([*args])
-        self.add(arr)
+        if self.shape == 1:
+            self.vals = np.append(self.vals, *args)
+        else:
+            arr = np.array([*args])
+            self.add(arr)
 
     def add(self, arr: np.ndarray):
         """Adds an array to the list.
@@ -85,8 +88,8 @@ class NDVariable:
 
     @property
     def value(self):
-        if self.shape == 1:
-            return self.vals[-1][0]
+        # if self.shape == 1:
+        # return self.vals[-1][0]
         return self.vals[-1]
 
     def get(self, dim: str):
@@ -125,6 +128,10 @@ class NDVariable:
         """
         return f"{self.name}: {self.with_unit}"
 
+    @property
+    def normal(self):
+        return np.linalg.norm(self.value)
+
     def __getitem__(self, key: int):
         return self.values[key]
 
